@@ -1,8 +1,8 @@
 #' Plot method for the \code{\link{trigrid}}, \code{\link{hexagrid}} or \code{\link{facelayer}} classes
 #' 
-#'	This function will invoke the \code{plot} method of the \code{\link[sp]{SpatialPolygons}} class.
+#'	This function will invoke the \code{plot} method of the \code{\link[sf:sf]{sf}} or the  \code{\link[sp]{SpatialPolygons}} class.
 #' @param x (\code{\link{trigrid}}, \code{\link{hexagrid}} or \code{\link{facelayer}}) The object to be plotted.
-#' @param projargs (\code{character} or \code{\link[sp:CRS-class]{CRS}}) A projection string for the transformation fo coordinates.
+#' @param crs (\code{character} or \code{\link[sf:st_crs]{crs}}) A coordinate system for the transformation of coordinates.
 #' @param ... Arguments passed to the \code{plot} function.
 #' @rdname plot
 #' @return The function has no return value.
@@ -14,38 +14,51 @@
 setMethod(
 	"plot",
 	signature="trigrid",
-	definition=function(x,projargs=NULL,...){
-		#if no @sp found
-		if(suppressWarnings(is.na(x@sp))){
-			stop("Slot @sp is empty. Use newsp() to add a 2d respresentation. ")
+	definition=function(x,crs=NULL,...){
+		
+		# detect the what is available 
+		sfplot <- FALSE
+		spplot <- FALSE
+		# these are missing values if they are not yet done
+		if(inherits(x@sf, "sf")) sfplot <- TRUE
+		if(inherits(x@sp, "Spatial")) spplot <- TRUE
+
+		# by default use the sf-method for plotting
+		if(sfplot){
+			if(!is.null(crs)){
+				x@sf <-sf::st_transform(x@sf, crs)
+			}
+			# use the plot method
+			plot(x@sf$geometry, ...)
 		}
 		
-		#transformation is necessary
-		if(!is.null(projargs)){
-			#	requireNamespace("rgdal")
-			if(requireNamespace("rgdal", quietly = TRUE)){
-				if(class(projargs)=="CRS"){
-					x@sp<-sp::spTransform(x@sp, projargs)
-				}
-				if(class(projargs)=="character"){
-					x@sp<-sp::spTransform(x@sp, sp::CRS(projargs))
-				}
-			} else{
-				stop("The rgdal package is required to appropriately project this object. ")
+		# if the sf slot is not available, use sp
+		if(spplot & (!sfplot)){
+
+			# if the crs is given, use sf to do the transformation
+			if(!is.null(crs)){
+				x@sp <- methods::as(sf::st_transform(sf::st_as_sf(x@sp), crs), "Spatial")
 			}
+			# use the plot method
+
+			sp::plot(x@sp, ...)
+		}
+
+		if(!sfplot & !spplot){
+			stop("Both the @sp and @sf is empty. Use newsf() to add a 2d respresentation. ")
 		}
-	
-		sp::plot(x@sp, ...)
-	#	rect(ytop=90, ybot=-90, xleft=-180, xright=180)
-	
 	}
 )
 
 #' Lines method for the \code{trigrid} and \code{hexagrid} classes
 #' 
-#' This function will invoke the \code{\link[sp:panel]{sp.lines}} method of the \code{\link[sp]{SpatialPolygons}} class.
+#' This function will invoke the method of the \code{\link[sp]{SpatialPolygons}} class.
+#'	This function will invoke the \code{lines} method of the \code{\link[sf:sf]{sf}} or the  \code{\link[sp]{SpatialPolygons}} class.
 #' @param x (\code{\link{trigrid}}, \code{\link{hexagrid}}) Object.
-#' @param projargs (\code{character} or \code{\link[sp:CRS-class]{CRS}}) A projection string for the transformation fo coordinates. 
+#' @param crs (\code{character} or \code{\link[sf:st_crs]{crs}}) A coordinate system for the transformation of coordinates.
+#' @param col Line colors - as in \code{\link[graphics:par]{par}}
+#' @param lwd Line thickness - as in \code{\link[graphics:par]{par}}
+#' @param lty Line type - as in \code{\link[graphics:par]{par}}
 #' @param ... Arguments passed to the \code{\link[sp:panel]{sp.lines}} method.
 #' @rdname lines-methods
 #' @return The function has no return value.
@@ -53,29 +66,9 @@ setMethod(
 setMethod(
 	"lines",
 	signature="trigrid",
-	definition=function(x,projargs=NULL,...){
-		#if no @sp found
-		if(suppressWarnings(is.na(x@sp))){
-			stop("Slot @sp is empty. Use newsp() to add a 2d respresentation. ")
-		}
-		
-		#transformation is necessary
-		if(!is.null(projargs)){
-			if(requireNamespace("rgdal", quietly = TRUE)){
-				if(class(projargs)=="CRS"){
-					x@sp<-sp::spTransform(x@sp, projargs)
-				}
-				if(class(projargs)=="character"){
-					x@sp<-sp::spTransform(x@sp, sp::CRS(projargs))
-				}	
-			} else{
-				stop("The 'rgdal' package is required to appropriately project this object. ")
-			}
-				
-		}
-		
-		# replace with sp::sp.lines()
-		sp::sp.lines(x@sp,...)
+	definition=function(x,crs=NULL,col=1, lwd=1, lty=1, ...){
+
+		plot(x, crs=crs, add=TRUE, border=col, lwd=lwd, lty=lty,...)
 	
 	}
 )
@@ -85,7 +78,7 @@ setMethod(
 #' This function will show where the grid elements are located.
 #' @param gridObj (\code{\link{trigrid}}, \code{\link{hexagrid}}) An icosahedral grid.
 #' @param type (\code{character}) The type of element to be plotted: either \code{"f"} (faces), \code{"v"} (vertices) or  \code{"e"} (edges).
-#' @param projargs (\code{character} or \code{\link[sp:CRS-class]{CRS}}) A projection string for the transformation fo coordinates.
+#' @param crs (\code{character} or \code{\link[sf:st_crs]{crs}}) A coordinate system for the transformation of coordinates.
 #' @param ... Arguments passed to the \code{\link[graphics]{text}} function.
 #' @return The function has no return value.
 #' @export
@@ -93,7 +86,7 @@ setMethod(
 #' gr <- hexagrid(sp=TRUE)
 #' plot(gr)
 #' gridlabs(gr)
-gridlabs<-function(gridObj,type="f",projargs=NULL,...){
+gridlabs<-function(gridObj,type="f",crs=NULL,...){
 	# center back to origin if not there already
 		if(gridObj@center[1]!=0 | gridObj@center[2]!=0 | gridObj@center[3]!=0){
 			gridObj<-translate(gridObj,-gridObj@center)
@@ -116,27 +109,17 @@ gridlabs<-function(gridObj,type="f",projargs=NULL,...){
 		coords<-CarToPol(coord3d, norad=TRUE, origin=gridObj@center)
 		
 	}
-	
-	spPoints<-sp::SpatialPoints(coords, proj4string=CRS("+proj=longlat +a=6371007 +b=6371007"))
+	sfPoints <- sf::st_as_sf(as.data.frame(coords), crs=gridObj@crs, coords=c("long", "lat"))
 	
 	#transformation is necessary
-	if(!is.null(projargs)){
-		#	requireNamespace("rgdal")
-		if(requireNamespace("rgdal", quietly = TRUE)){
-			if(class(projargs)=="CRS"){
-				spPoints<-sp::spTransform(spPoints, projargs)
-			}
-			if(class(projargs)=="character"){
-				spPoints<-sp::spTransform(spPoints, sp::CRS(projargs))
-			}
-
-		} else{
-			stop("The rgdal package is required to appropriately project this object. ")
-		}
-		
+	if(!is.null(crs)){
+		sfPoints <- sf::st_transform(sfPoints, crs=crs)
 	}
+
+	# detach coordinates
+	newCoords <- sf::st_coordinates(sfPoints)
 	
-	graphics::text(labels=texts, x=spPoints@coords[,1], y=spPoints@coords[,2],...)
+	graphics::text(labels=texts, x=newCoords[,1], y=newCoords[,2],...)
 	
 }
 
